@@ -1,8 +1,9 @@
 from django.contrib import admin
 
-from models import Article, Tag, Comment
+from models import Article, Tag, Comment, Link
 
 
 admin.site.register(Article)
 admin.site.register(Tag)
-admin.site.register(Comment)
\ No newline at end of file
+admin.site.register(Comment)
+admin.site.register(Link)
\ No newline at end of file
