@@ -1,11 +1,12 @@
-from models import Tag
+from models import Tag, Link
 
 import settings
 
 def base(request):
     tags = Tag.objects.order_by("name")
+    links = Link.objects.order_by("name")
     base_labels = {
         "header": settings.SIMPLEBLOG_HEADER,
         "domain": settings.SIMPLEBLOG_DOMAIN,
     }
-    return {"base_tags": tags, "base_labels": base_labels, }
\ No newline at end of file
+    return {"base_tags": tags, "base_labels": base_labels, "base_links": links, }
\ No newline at end of file
